@@ -1,6 +1,6 @@
 import abc
 import typing as t
-from uuid import uuid4, UUID
+from uuid import uuid4
 
 from dddmisc.messages import DDDEvent
 
@@ -12,7 +12,7 @@ class BaseAggregate(abc.ABC):
         self._events = set()
 
     @property
-    def reference(self) -> UUID:
+    def reference(self):
         return self._reference
 
     @t.final
@@ -30,3 +30,8 @@ class BaseAggregate(abc.ABC):
 
     def __hash__(self):
         return hash(self.reference)
+
+    def check_by_parameters(self, **kwargs):
+        if 'reference' in kwargs:
+            return self.reference == kwargs['reference']
+        return False
